@@ -1,6 +1,7 @@
 heckitVcov <- function( xMat, wMat, vcovProbit, rho, delta, sigma,
    saveMemory = TRUE ) {
-
+   if(is.null(vcovProbit))
+       return(NA)
    if( saveMemory ) {
       txdMat <- t( xMat )
       for( i in 1:nrow( txdMat ) ) {
